[][src]Enum probe_rs::architecture::arm::memory::Component

pub enum Component {
    GenericVerificationComponent(ComponentId),
    Class1RomTable(ComponentId, RomTable),
    Class9RomTable(ComponentId),
    PeripheralTestBlock(ComponentId),
    GenericIPComponent(ComponentId),
    CoreLinkOrPrimeCellOrSystemComponent(ComponentId),
}

This enum describes a CoreSight component. Described in table D1-2 in the ADIv5.2 spec.

Variants

GenericVerificationComponent(ComponentId)
Class1RomTable(ComponentId, RomTable)
Class9RomTable(ComponentId)
PeripheralTestBlock(ComponentId)
GenericIPComponent(ComponentId)
CoreLinkOrPrimeCellOrSystemComponent(ComponentId)

Implementations

impl Component[src]

pub fn try_parse<'probe: 'memory, 'memory>(
    memory: &'memory mut Memory<'probe>,
    baseaddr: u64
) -> Result<Component, RomTableError>
[src]

Tries to parse a CoreSight component table.

pub fn id(&self) -> &ComponentId[src]

pub fn read_reg(&self, core: &mut Core<'_>, offset: u32) -> Result<u32, Error>[src]

Reads a register of the component pointed to by this romtable entry.

pub fn write_reg(
    &self,
    core: &mut Core<'_>,
    offset: u32,
    value: u32
) -> Result<(), Error>
[src]

Writes a register of the component pointed to by this romtable entry.

pub fn tpiu<'probe: 'core, 'core>(
    &'core self,
    core: &'core mut Core<'probe>
) -> Result<Tpiu<'probe, 'core>, RomTableError>
[src]

Returns the TPIU component if there is any.

pub fn dwt<'probe: 'core, 'core>(
    &'core self,
    core: &'core mut Core<'probe>
) -> Result<Dwt<'probe, 'core>, RomTableError>
[src]

Returns the DWT component if there is any.

pub fn itm<'probe: 'core, 'core>(
    &'core self,
    core: &'core mut Core<'probe>
) -> Result<Itm<'probe, 'core>, RomTableError>
[src]

Returns the ITM component if there is any.

pub fn iter(&self) -> ComponentIter<'_>[src]