pub struct FlashProperties {
    pub address_range: Range<u64>,
    pub page_size: u32,
    pub erased_byte_value: u8,
    pub program_page_timeout: u32,
    pub erase_sector_timeout: u32,
    pub sectors: Vec<SectorDescription, Global>,
}
Properties of flash memory, which are used when programming Flash memory.

These values are read from the YAML target description files.

Fields

address_range: Range<u64>

The range of the device flash.

page_size: u32

The page size of the device flash.

erased_byte_value: u8

The value of a byte in flash that was just erased.

program_page_timeout: u32

The approximative time it takes to program a page.

erase_sector_timeout: u32

The approximative time it takes to erase a sector.

sectors: Vec<SectorDescription, Global>

The available sectors of the device flash.