pub enum SteppingMode {
    BreakPoint,
    StepInstruction,
    OverStatement,
    IntoStatement,
    OutOfStatement,
}
Stepping granularity for stepping through a program during debug.

Variants



BreakPoint

Special case, where we aren’t stepping, but we are trying to find the next valid breakpoint.

  • The validity of halt locations are defined as target instructions that live between the end of the prologue, and the start of the end sequence of a gimli::read::LineRow.


StepInstruction

Advance one machine instruction at a time.



OverStatement

Step Over the current statement, and halt at the start of the next statement.



IntoStatement

Use best efforts to determine the location of any function calls in this statement, and step into them.



OutOfStatement

Step to the calling statement, immediately after the current function returns.

Implementations

source

impl SteppingMode

source

pub fn step(
&self,
core: &mut Core<'_>,
debug_info: &DebugInfo
) -> Result<(CoreStatus, u64), DebugError>

Determine the program counter location where the SteppingMode is aimed, and step to it. Return the new CoreStatus and program_counter value.

Implementation Notes for stepping at statement granularity:

  • If a hardware breakpoint is available, we will set it at the desired location, run to it, and release it.
  • If no hardware breakpoints are available, we will do repeated instruction steps until we reach the desired location.

Usage Note:

  • Currently, no special provision is made for the effect of interrupts that get triggered during stepping. The user must ensure that interrupts are disabled during stepping, or accept that stepping may be diverted by the interrupt processing on the core.