Struct probe_rs::debug::SourceLocation
source · pub struct SourceLocation {
pub line: Option<u64>,
pub column: Option<ColumnType>,
pub file: Option<String>,
pub directory: Option<PathBuf>,
pub low_pc: Option<u32>,
pub high_pc: Option<u32>,
}Expand description
A specific location in source code.
Fields
line: Option<u64>The line number in the source file with zero based indexing.
column: Option<ColumnType>The column number in the source file with zero based indexing.
file: Option<String>The file name of the source file.
directory: Option<PathBuf>The directory of the source file.
low_pc: Option<u32>The address of the first instruction associated with the source code
high_pc: Option<u32>The address of the first location past the last instruction associated with the source code