pub enum VariableLocation {
    Unknown,
    Unavailable,
    Address(u64),
    Value,
    Error(String),
    Unsupported(String),
}
Location of a variable

Variants



Unknown

Location of the variable is not known. This means that it has not been evaluated yet.



Unavailable

The variable does not have a location currently, probably due to optimisations.



Address(u64)

The variable can be found in memory, at this address.



Value

The value of the variable is directly available.



Error(String)

There was an error evaluating the variable location.



Unsupported(String)

Support for handling the location of this variable is not (yet) implemented.

Implementations

source

impl VariableLocation

source

pub fn memory_address(&self) -> Result<u64, DebugError>

Return the memory address, if available. Otherwise an error is returned.

source

pub fn valid(&self) -> bool

Check if the location is valid, ie. not an error, unsupported, or unavailable.