pub enum VariableName {
    StaticScopeRoot,
    RegistersRoot,
    LocalScopeRoot,
    PeripheralScopeRoot,
    Artifical,
    AnonymousNamespace,
    Namespace(String),
    Named(String),
    Unknown,
}
The type of variable we have at hand.

Variants



StaticScopeRoot

Top-level variable for static variables, child of a stack frame variable, and holds all the static scoped variables which are directly visible to the compile unit of the frame.



RegistersRoot

Top-level variable for registers, child of a stack frame variable.



LocalScopeRoot

Top-level variable for local scoped variables, child of a stack frame variable.



PeripheralScopeRoot

Top-level variable for CMSIS-SVD file Device peripherals/registers/fields.



Artifical

Artificial variable, without a name (e.g. enum discriminant)



AnonymousNamespace

Anonymous namespace



Namespace(String)

A Namespace with a specific name



Named(String)

Variable with a specific name



Unknown

Variable with an unknown name