pub enum VariableType {
    Base(String),
    Struct(String),
    Enum(String),
    Namespace,
    Pointer(Option<String>),
    Array {
        item_type_name: String,
        count: usize,
    },
    Unknown,
    Other(String),
}
The variants of VariableType allows us to streamline the conditional logic that requires specific handling depending on the nature of the variable.

Variants



Base(String)

A variable with a Rust base datatype.



Struct(String)

A Rust struct.



Enum(String)

A Rust enum.



Namespace

Namespace refers to the path that qualifies a variable. e.g. “std::string” is the namespace for the strucct “String”



Pointer(Option<String>)

A Pointer is a variable that contains a reference to another variable, and the type of the referenced variable may not be known until the reference has been resolved.



Array

Fields

item_type_name: String

The type name of the variable.

count: usize

The number of entries in the array.

A Rust array.



Unknown

When we are unable to determine the name of a variable.



Other(String)

For infrequently used categories of variables that does not fall into any of the other VriableType variants.

Implementations

source

impl VariableType

source

pub fn is_phantom_data(&self) -> bool

A Rust PhantomData type used as a marker for to “act like” they own a specific type.

source

pub fn is_reference(&self) -> bool

This variable is a reference to another variable.

source

pub fn is_array(&self) -> bool

This variable is an array, and requires special processing during