pub enum VariableValue {
    Valid(String),
    Error(String),
    Empty,
}
A Variable will have either a valid value, or some reason why a value could not be constructed.

  • If we encounter expected errors, they will be displayed to the user as defined below.
  • If we encounter unexpected errors, they will be treated as proper errors and will propogated to the calling process as an Err()

Variants



Valid(String)

A valid value of this variable



Error(String)

Notify the user that we encountered a problem correctly resolving the variable.

  • The variable will be visible to the user, as will the other field of the variable.
  • The contained warning message will be displayed to the user.
  • The debugger will not attempt to resolve additional fields or children of this variable.


Empty

The value has not been set. This could be because …

  • It is too early in the process to have discovered its value, or …
  • The variable cannot have a stored value, e.g. a struct. In this case, please use Variable::get_value to infer a human readable value from the value of the struct’s fields.

Implementations

source

impl VariableValue

source

pub fn is_valid(&self) -> bool

A VariableValue is valid if it doesn’t contain an Info or a Warning.

source

pub fn is_empty(&self) -> bool

No value or error is present