pub struct VariableCache { /* private fields */ }
VariableCache stores available Variables, and provides methods to create and navigate the parent-child relationships of the Variables.

Implementations

source

impl VariableCache

source

pub fn new() -> Self

Creates a new VariableCache.

source

pub fn cache_variable(
&mut self,
parent_key: Option<i64>,
cache_variable: Variable,
core: &mut Core<'_>
) -> Result<Variable, Error>

Performs an add or update of a probe_rs::debug::Variable to the cache, consuming the input and returning a Clone.

  • Add operation: If the Variable::variable_key is 0, then assign a key and store it in the cache.
    • Return an updated Clone of the stored variable
  • Update operation: If the Variable::variable_key is > 0
    • If the key value exists in the cache, update it, Return an updated Clone of the variable.
    • If the key value doesn’t exist in the cache, Return an error.
  • For all operations, update the parent_key. A value of None means there are no parents for this variable.
    • Validate that the supplied Variable::parent_key is a valid entry in the cache.
  • If appropriate, the Variable::value is updated from the core memory, and can be used by the calling function.
source

pub fn get_variable_by_key(&self, variable_key: i64) -> Option<Variable>

Retrieve a clone of a specific Variable, using the variable_key.

source

pub fn get_variable_by_name_and_parent(
&self,
variable_name: &VariableName,
parent_key: Option<i64>
) -> Option<Variable>

Retrieve a clone of a specific Variable, using the name and parent_key. If there is more than one, it will be logged (tracing::error!), and only the last will be returned.

source

pub fn get_variable_by_name(
&self,
variable_name: &VariableName
) -> Option<Variable>

Retrieve a clone of a specific Variable, using the name. If there is more than one, it will be logged (tracing::warn!), and only the first will be returned. It is possible for a hierarchy of variables in a cache to have duplicate names under different parents.

source

pub fn get_children(
&self,
parent_key: Option<i64>
) -> Result<Vec<Variable>, Error>

Retrieve cloned version of all the children of a Variable. If parent_key == None, it will return all the top level variables (no parents) in this cache.

source

pub fn has_children(&self, parent_variable: &Variable) -> Result<bool, Error>

Check if a Variable has any children. This also validates that the parent exists in the cache, before attempting to check for children.

source

pub fn adopt_grand_children(
&mut self,
parent_variable: &Variable,
obsolete_child_variable: &Variable
) -> Result<(), Error>

Sometimes DWARF uses intermediate nodes that are not part of the coded variable structure. When we encounter them, the children of such intermediate nodes are assigned to the parent of the intermediate node, and we discard the intermediate nodes from the DebugInfo::VariableCache

Similarly, while resolving VariableNodeType::is_deferred(), i.e. ‘lazy load’ of variables, we need to create intermediate variables that are eliminated here.

NOTE: For all other situations, this function will silently do nothing.

source

pub fn remove_cache_entry_children(
&mut self,
parent_variable_key: i64
) -> Result<(), Error>

Removing an entry’s children from the VariableCache will recursively remove all their children

source

pub fn remove_cache_entry(&mut self, variable_key: i64) -> Result<(), Error>

Removing an entry from the VariableCache will recursively remove all its children