Enum probe_rs::CoreType

source ·
pub enum CoreType {
    Armv6m,
    Armv7a,
    Armv7m,
    Armv7em,
    Armv8a,
    Armv8m,
    Riscv,
}
Type of a supported core.

Variants



Armv6m

ARMv6-M: Cortex M0, M0+, M1



Armv7a

ARMv7-A: Cortex A7, A9, A15



Armv7m

ARMv7-M: Cortex M3



Armv7em

ARMv7e-M: Cortex M4, M7



Armv8a

ARMv7-A: Cortex A35, A55, A72



Armv8m

ARMv8-M: Cortex M23, M33



Riscv

RISC-V

Implementations

source

impl CoreType

source

pub fn is_cortex_m(&self) -> bool

Returns true if the core type is an ARM Cortex-M

source

impl CoreType

source

pub fn architecture(&self) -> Architecture

Returns the parent architecture family of this core type.