Enum probe_rs::Error

source ·
pub enum Error {
    Probe(DebugProbeError),
    Arm(ArmError),
    Riscv(RiscvError),
    UnableToOpenProbe(&'static str),
    CoreNotFound(usize),
    ChipNotFound(RegistryError),
    MissingPermissions(String),
    Other(Error),
    Timeout,
    MemoryNotAligned {
        address: u64,
        alignment: usize,
    },
}
The overarching error type which contains all possible errors as variants.

Variants



Probe(DebugProbeError)

An error in the probe driver occurred.



Arm(ArmError)

An ARM specific error occured.



Riscv(RiscvError)

A RISCV specific error occured.



UnableToOpenProbe(&'static str)

The probe could not be opened.



CoreNotFound(usize)

The core with given ID does not exist.



ChipNotFound(RegistryError)

The given chip does not exist.



MissingPermissions(String)

An operation was not performed because the required permissions were not given.

This can for example happen when the core is locked and needs to be erased to be unlocked. Then the correct permission needs to be given to automatically unlock the core to prevent accidental erases.



Other(Error)

Any other error occurred.



Timeout

A timeout occured during an operation



MemoryNotAligned

Fields

address: u64

The address of the register.

alignment: usize

The required alignment in bytes (address increments).

Unaligned memory access