pub enum InstructionSet {
Thumb2,
A32,
A64,
RV32,
RV32C,
RV64,
RV64C,
Xtensa,
}Expand description
Instruction set used by a core
Variants
Thumb2
ARM Thumb 2 instruction set
A32
ARM A32 (often just called ARM) instruction set
A64
ARM A64 (aarch64) instruction set
RV32
RISC-V 32-bit uncompressed instruction sets (RV32) - covers all ISA variants that use 32-bit instructions.
RV32C
RISC-V 32-bit compressed instruction sets (RV32C) - covers all ISA variants that allow compressed 16-bit instructions.
RV64
RISC-V 64-bit uncompressed instruction sets (RV64) - covers all ISA variants that use 32-bit instructions in 64-bit mode.
RV64C
RISC-V 64-bit compressed instruction sets (RV64C) - covers all ISA variants that allow compressed 16-bit instructions in 64-bit mode.
Xtensa
Xtensa instruction set
Implementations
Sourceimpl InstructionSet
impl InstructionSet
Sourcepub fn from_target_triple(triple: &str) -> Option<InstructionSet>
pub fn from_target_triple(triple: &str) -> Option<InstructionSet>
Get the instruction set from a rustc target triple.
Sourcepub fn get_minimum_instruction_size(&self) -> u8
pub fn get_minimum_instruction_size(&self) -> u8
Get the minimum instruction size in bytes.
Sourcepub fn get_maximum_instruction_size(&self) -> u8
pub fn get_maximum_instruction_size(&self) -> u8
Get the maximum instruction size in bytes. All supported architectures have a maximum instruction size of 4 bytes.
Sourcepub fn is_compatible(&self, instr_set: InstructionSet) -> bool
pub fn is_compatible(&self, instr_set: InstructionSet) -> bool
Returns whether a CPU with the self instruction set is compatible with a program compiled for instr_set.