Enum probe_rs::flashing::FileDownloadError[][src]

pub enum FileDownloadError {
    Flash(FlashError),
    IhexRead(ReaderError),
    IO(Error),
    Object(&'static str),
    Elf(Error),
    NoLoadableSegments,
}
A finite list of all the errors that can occur when flashing a given file.

This includes corrupt file issues, OS permission issues as well as chip connectivity and memory boundary issues.

Variants

Flash(FlashError)

Tuple Fields

An error with the actual flashing procedure has occured.

This is mostly an error in the communication with the target inflicted by a bad hardware connection or a probe-rs bug.

IhexRead(ReaderError)

Tuple Fields

Reading and decoding the IHEX file has failed due to the given error.

IO(Error)

Tuple Fields

0: Error

An IO error has occured while reading the firmware file.

Object(&'static str)

Tuple Fields

0: &'static str

The given error has occured while reading the object file.

Elf(Error)

Tuple Fields

0: Error

Reading and decoding the given ELF file has resulted in the given error.

NoLoadableSegments

No loadable segments were found in the ELF file.

This is most likely because of a bad linker script.