pub struct FlashAlgorithm {Show 22 fields
pub name: String,
pub default: bool,
pub load_address: u64,
pub instructions: Vec<u32>,
pub pc_init: Option<u64>,
pub pc_uninit: Option<u64>,
pub pc_program_page: u64,
pub pc_erase_sector: u64,
pub pc_erase_all: Option<u64>,
pub pc_verify: Option<u64>,
pub pc_blank_check: Option<u64>,
pub pc_read: Option<u64>,
pub pc_flash_size: Option<u64>,
pub static_base: u64,
pub stack_top: u64,
pub stack_size: u64,
pub stack_overflow_check: bool,
pub page_buffers: Vec<u64>,
pub rtt_control_block: Option<u64>,
pub rtt_poll_interval: u64,
pub flash_properties: FlashProperties,
pub transfer_encoding: TransferEncoding,
}Expand description
A flash algorithm, which has been assembled for a specific chip.
To create a FlashAlgorithm, call the assemble_from_raw function.
Fields
name: StringThe name of the flash algorithm.
default: boolWhether this flash algorithm is the default one or not.
load_address: u64Memory address where the flash algo instructions will be loaded to.
instructions: Vec<u32>List of 32-bit words containing the position-independent code for the algo.
pc_init: Option<u64>Address of the Init() entry point. Optional.
pc_uninit: Option<u64>Address of the UnInit() entry point. Optional.
pc_program_page: u64Address of the ProgramPage() entry point.
pc_erase_sector: u64Address of the EraseSector() entry point.
pc_erase_all: Option<u64>Address of the EraseAll() entry point. Optional.
pc_verify: Option<u64>Address of the Verify() entry point. Optional.
pc_blank_check: Option<u64>Address of the BlankCheck() entry point. Optional.
pc_read: Option<u64>Address of the (non-standard) ReadFlash() entry point. Optional.
pc_flash_size: Option<u64>Address of the (non-standard) FlashSize() entry point. Optional.
static_base: u64Initial value of the R9 register for calling flash algo entry points, which determines where the position-independent data resides.
stack_top: u64Initial value of the stack pointer when calling any flash algo API.
stack_size: u64The size of the stack in bytes.
stack_overflow_check: boolWhether to check for stack overflows.
page_buffers: Vec<u64>A list of base addresses for page buffers. The buffers must be at
least as large as the region’s page_size attribute. If at least 2 buffers are included in
the list, then double buffered programming will be enabled.
rtt_control_block: Option<u64>Location of optional RTT control block.
If this is present, the flash algorithm supports debug output over RTT.
rtt_poll_interval: u64Milliseconds between RTT polls.
flash_properties: FlashPropertiesThe properties of the flash on the device.
transfer_encoding: TransferEncodingThe encoding format accepted by the flash algorithm.
Implementations
Sourceimpl FlashAlgorithm
impl FlashAlgorithm
Sourcepub fn sector_info(&self, address: u64) -> Option<SectorInfo>
pub fn sector_info(&self, address: u64) -> Option<SectorInfo>
Try to retrieve the information about the flash sector
which contains address.
If the address is not part of the flash, None will
be returned.
Sourcepub fn page_info(&self, address: u64) -> Option<PageInfo>
pub fn page_info(&self, address: u64) -> Option<PageInfo>
Returns the necessary information about the page which address resides in
if the address is inside the flash region.
Sourcepub fn iter_sectors(&self) -> impl Iterator<Item = SectorInfo> + '_
pub fn iter_sectors(&self) -> impl Iterator<Item = SectorInfo> + '_
Iterate over all the sectors of the flash.
Sourcepub fn iter_pages(&self) -> impl Iterator<Item = PageInfo> + '_
pub fn iter_pages(&self) -> impl Iterator<Item = PageInfo> + '_
Iterate over all the pages of the flash.
Sourcepub fn is_erased(&self, data: &[u8]) -> bool
pub fn is_erased(&self, data: &[u8]) -> bool
Returns true if the entire contents of the argument array equal the erased byte value.
Sourcepub fn get_max_algorithm_header_size() -> u64
pub fn get_max_algorithm_header_size() -> u64
When the target architecture is not known, and we need to allocate space for the header, this function returns the maximum size of the header of supported architectures.
Sourcepub fn assemble_from_raw(
raw: &RawFlashAlgorithm,
ram_region: &RamRegion,
target: &Target,
) -> Result<Self, FlashError>
pub fn assemble_from_raw( raw: &RawFlashAlgorithm, ram_region: &RamRegion, target: &Target, ) -> Result<Self, FlashError>
Constructs a complete flash algorithm, tailored to the flash and RAM sizes given.
Sourcepub fn assemble_from_raw_with_data(
raw: &RawFlashAlgorithm,
ram_region: &RamRegion,
data_ram_region: &RamRegion,
target: &Target,
) -> Result<Self, FlashError>
pub fn assemble_from_raw_with_data( raw: &RawFlashAlgorithm, ram_region: &RamRegion, data_ram_region: &RamRegion, target: &Target, ) -> Result<Self, FlashError>
Constructs a complete flash algorithm, tailored to the flash and RAM sizes given.