pub struct FlashLoader { /* private fields */ }
FlashLoader is a struct which manages the flashing of any chunks of data onto any sections of flash.

Use add_data() to add a chunk of data. Once you are done adding all your data, use commit() to flash the data. The flash loader will make sure to select the appropriate flash region for the right data chunks. Region crossing data chunks are allowed as long as the regions are contiguous.

Implementations

source

impl FlashLoader

source

pub fn new(
memory_map: Vec<MemoryRegion>,
source: TargetDescriptionSource
) -> Self

Create a new flash loader.

source

pub fn add_data(&mut self, address: u64, data: &[u8]) -> Result<(), FlashError>

Stages a chunk of data to be programmed.

The chunk can cross flash boundaries as long as one flash region connects to another flash region.

source

pub fn load_bin_data<T: Read + Seek>(
&mut self,
file: &mut T,
options: BinOptions
) -> Result<(), FileDownloadError>

Reads the data from the binary file and adds it to the loader without splitting it into flash instructions yet.

source

pub fn load_hex_data<T: Read + Seek>(
&mut self,
file: &mut T
) -> Result<(), FileDownloadError>

Reads the HEX data segments and adds them as loadable data blocks to the loader. This does not create and flash loader instructions yet.

source

pub fn load_elf_data<T: Read>(
&mut self,
file: &mut T
) -> Result<(), FileDownloadError>

Prepares the data sections that have to be loaded into flash from an ELF file. This will validate the ELF file and transform all its data into sections but no flash loader commands yet.

source

pub fn commit(
&self,
session: &mut Session,
options: DownloadOptions
) -> Result<(), FlashError>

Writes all the stored data chunks to flash.

Requires a session with an attached target that has a known flash algorithm.

If do_chip_erase is true the entire flash will be erased.

source

pub fn data(&self) -> impl Iterator<Item = (u64, &[u8])>

Return data chunks stored in the FlashLoader as pairs of address and bytes.