Struct probe_rs::flashing::FlashProgress [−][src]
pub struct FlashProgress { /* fields omitted */ }Expand description
A structure to manage the flashing procedure progress reporting.
This struct stores a handler closure which will be called everytime an event happens during the flashing process. Such an event can be start or finish of the flashing procedure or a progress report, as well as some more events.
Example
use probe_rs::flashing::FlashProgress;
// Print events
let progress = FlashProgress::new(|event| println!("Event: {:#?}", event));Implementations
Create a new FlashProgress structure with a given handler to be called on events.