Struct probe_rs::Core [−][src]
pub struct Core<'probe> { /* fields omitted */ }Implementations
Wait until the core is halted. If the core does not halt on its own,
a DebugProbeError::Timeout error will be returned.
Check if the core is halted. If the core does not halt on its own,
a DebugProbeError::Timeout error will be returned.
Try to halt the core. This function ensures the core is actually halted, and
returns a DebugProbeError::Timeout otherwise.
Reset the core, and then continue to execute instructions. If the core
should be halted after reset, use the reset_and_halt function.
Reset the core, and then immediately halt. To continue execution after
reset, use the reset function.
Steps one instruction and then enters halted state again.
pub fn read_core_reg(
&mut self,
address: impl Into<CoreRegisterAddress>
) -> Result<u32, Error>
pub fn write_core_reg(
&mut self,
address: CoreRegisterAddress,
value: u32
) -> Result<(), Error>
Set a hardware breakpoint
This function will try to set a hardware breakpoint. The amount
of hardware breakpoints which are supported is chip specific,
and can be queried using the get_available_breakpoint_units function.
Clear all hardware breakpoints
This function will clear all HW breakpoints which are configured on the target,
regardless if they are set by probe-rs, AND regardless if they are enabled or not.
Also used as a helper function in Session::drop.