Struct probe_rs::FakeProbe

source ·
pub struct FakeProbe { /* private fields */ }
This is a mock probe which can be used for mocking things in tests or for dry runs.

Implementations

source

impl FakeProbe

source

pub fn new() -> Self

Creates a new FakeProbe for mocking.

source

pub fn set_dap_register_read_handler(
&mut self,
handler: Box<dyn Fn(PortType, u8) -> Result<u32, ArmError> + Send>
)

This sets the read handler for DAP register reads. Can be used to hook into the read.

source

pub fn set_dap_register_write_handler(
&mut self,
handler: Box<dyn Fn(PortType, u8, u32) -> Result<(), ArmError> + Send>
)

This sets the write handler for DAP register writes. Can be used to hook into the write.

source

pub fn into_probe(self) -> Probe

Makes a generic probe out of the FakeProbe