Enum probe_rs::flashing::ProgressEvent[][src]

pub enum ProgressEvent {
Show 13 variants Initialized { flash_layout: FlashLayout, }, StartedFilling, PageFilled { size: u32, time: Duration, }, FailedFilling, FinishedFilling, StartedErasing, SectorErased { size: u32, time: Duration, }, FailedErasing, FinishedErasing, StartedProgramming, PageProgrammed { size: u32, time: Duration, }, FailedProgramming, FinishedProgramming,
}
Possible events during the flashing process.

If flashing works without problems, the events will arrive in the following order:

  • Initialized
  • StartedFilling
  • PageFilled for every page
  • FinishedFilling
  • StartedErasing
  • SectorErased for every sector
  • FinishedErasing
  • StartedProgramming
  • PageProgrammed for every page
  • FinishedProgramming

If an erorr occurs in any stage, one of the Failed* event will be returned, and no further events will be returned.

Variants

Initialized

Fields

flash_layout: FlashLayout

The layout of the flash contents as it will be used by the flash procedure. This is an exact report of what the flashing procedure will do during the flashing process.

The flash layout has been built and the flashing procedure was initialized.

StartedFilling

Filling of flash pages has started.

PageFilled

Fields

size: u32

The size of the page in bytes.

time: Duration

The time it took to fill this flash page.

A page has been filled successfully. This does not mean the page has been programmed yet. Only its contents are determined at this point!

FailedFilling

Filling of the pages has failed.

FinishedFilling

Filling of the pages has finished successfully.

StartedErasing

Erasing of flash has started.

SectorErased

Fields

size: u32

The size of the sector in bytes.

time: Duration

The time it took to erase this sector.

A sector has been erased successfully.

FailedErasing

Erasing of the flash has failed.

FinishedErasing

Erasing of the flash has finished successfully.

StartedProgramming

Programming of the flash has started.

PageProgrammed

Fields

size: u32

The size of this page in bytes.

time: Duration

The time it took to program this page.

A flash page has been programmed successfully.

FailedProgramming

Programming of the flash failed.

FinishedProgramming

Programming of the flash has finished successfully.