Plugin system for probe-rs.
This module contains the interfaces necessary to define and register plugins. Plugins can extend the functionality of probe-rs by adding e.g. new targets, probes, image formats.
Plugins are registered by calling the register_plugin function.
Structs
- Plugin
- A plugin that can extend the functionality of probe-rs.
Functions
- register_
plugin - Register a plugin.